Crate fromsoftware_shared

Crate fromsoftware_shared 

Re-exports

pub use arxan::*;
pub use dl_math::*;
pub use empty::*;
pub use game_version::*;
pub use owned_pointer::*;
pub use program::*;
pub use rtti::*;
pub use steam::*;
pub use stepper::*;
pub use task::*;
pub use util::*;

Modules

arxan
dl_math
empty
ext
game_version
owned_pointer
program
rtti
steam
stepper
task
util

Structs

AllocError
An error indicating that an allocation failed for any reason, including memory exhaustion or because the requested layout didn’t meet the allocator’s alignment requirements.
NoOpAllocator
A GameAllocator that never actually allocates or drops memory.
TryFromSuperclassError
The error type returend when a superclass isn’t an instance of a subclass.
UnknownPtr
A pointer whose target has not yet been reverse-engineered.

Enums

InstanceError
An error type returned by FromStatic::instance.

Traits

FromSingleton
Assigns a type a name that can be used for Dantelion2 singleton reflection.
FromStatic
A trait for all objects that are instantiated a single time at a fixed point in memory.
GameAllocator
A trait for global allocators within a game that are able to deallocate any memory on the game’s main heap. Generally corresponds to the drop logic for DLUT::DLAutoDeletePtr in games from Bloodborne forward.
Researching
A trait that’s intended to be applied to a type using a derive macro when actively trying to research the behavior and meaning of that type’s fields.
Subclass
A trait for C++ subclasses of the superclass T. Implementing this trait makes it possible for Rust code to be generic over all subclasses of a given C++ supertype.
Superclass
A trait for C++ types that have multiple different subclasses. Implementing this for a superclass and Subclass for its subclasses makes it possible to safely check for the object’s actual type based on its vtable.

Functions

load_static_direct
Loads a static reference to T from an Rva that points directly to its memory. Because this always assumes that the underlying object is initialized, it can only return InstanceError::Null if rva itself is 0.
load_static_indirect
Loads a static reference to T from an Rva that points to a pointer to its memory.

Type Aliases

InstanceResult
A Result whose error type is InstanceError.

Attribute Macros

for_all_subclasses
A proc macro attribute for defining an extension trait that makes a set of methods available for all subclasses of a superclass.
multi_param
Annotates a trait to automatically generate getters and setters that forward to methods of the same name in various structs.
singleton
Annotates a struct as a Dantelion2 singleton to be looked up using a single string argument.

Derive Macros

Researching
A derive macro for fromsoftware_shared::Researching that automatically makes all unk fields (public or private) available through Researching::unknown_fields.
StepperStates
A derive macro that implements the StepperStates trait on a given enum.
Subclass
A derive macro for fromsoftware_shared::Subclass.
Superclass
A derive macro for fromsoftware_shared::Superclass.