pub fn load_static_direct<T: FromStatic>(rva: Rva) -> InstanceResult<*mut T>Expand description
Loads a static reference to T from an Rva that points directly to its
memory. Because this always assumes that the underlying object is
initialized, it can only return InstanceError::Null if rva itself is 0.