load_static_indirect

Function load_static_indirect 

pub unsafe fn load_static_indirect<T: FromStatic>(
    rva: Rva,
) -> InstanceResult<*mut T>
Loads a static reference to T from an Rva that points to a pointer to its memory.

Safety

The caller must ensure that rva points to a pointer.