UnknownPtr

Struct UnknownPtr 

pub struct UnknownPtr(/* private fields */);
A pointer whose target has not yet been reverse-engineered.

Safety

This may be null and has no particular alignment requirements, but it does require that if it’s not nullit must point within the current process’s memory space.

Implementations

Source

impl UnknownPtr

pub unsafe fn from(value: usize) -> Self

Interprets value as a pointer.

Safety

The caller must ensure that value is either 0 or a valid address in the current address space.

pub fn rtti_classname(&self) -> Option<String>

Returns the class name for this pointer, if it’s pointing to a vftable whose name is in the RTTI.

pub fn is_null(&self) -> bool

Returns true if this pointer is null.

pub fn cast<T>(self) -> *const T

Casts this to a pointer to T.

pub fn addr(self) -> usize

Gets the “address” portion of the pointer.