Module util

Module util 

Structs

IncompleteArrayField
This is an adaptation of the __IncompleteArrayField type that rust-bindgen generates.
UnknownStruct
An opaque, still-unreversed native structure. This is equivalent to a u8 array, but its use indicates that we know a structure exists and we know its size but we don’t know its purpose or anything else about it.