An error indicating that an allocation failed for any reason, including
memory exhaustion or because the requested layout didn’t meet the
allocator’s alignment requirements.
A trait for global allocators within a game that are able to deallocate any
memory on the game’s main heap. Generally corresponds to the drop logic for
DLUT::DLAutoDeletePtr in games from Bloodborne forward.
A trait for C++ subclasses of the superclass T. Implementing this trait
makes it possible for Rust code to be generic over all subclasses of a given
C++ supertype.
A trait for C++ types that have multiple different subclasses. Implementing
this for a superclass and Subclass for its subclasses makes it possible to
safely check for the object’s actual type based on its vtable.
Loads a static reference to T from an Rva that points directly to its
memory. Because this always assumes that the underlying object is
initialized, it can only return InstanceError::Null if rva itself is 0.
A derive macro for fromsoftware_shared::Researching that automatically
makes all unk fields (public or private) available through
Researching::unknown_fields.