pub struct NoOpAllocator;Expand description
A GameAllocator that never actually allocates or drops memory.
allocate always returns AllocError and deallocate always panics.
This is intended to by used as the allocator for types such as OwnedPtr
that represent memory allocated by the game that don’t use the game’s main
heap and so whose deallocation behavior is unknown. It’s always incorrect to
try to create or destroy such types in Rust code.
Because NoOpAllocator::deallocate never has undefined behavior for any
memory blocks, all allocators are technically compatible with it.