pub struct UnknownPtr(/* private fields */);Expand description
A pointer whose target has not yet been reverse-engineered.
Safety
This may be null and has no particular alignment requirements, but it does require that if it’s not nullit must point within the current process’s memory space.
Implementations
Sourceimpl UnknownPtr
impl UnknownPtr
Sourcepub unsafe fn from(value: usize) -> Self
pub unsafe fn from(value: usize) -> Self
Interprets value as a pointer.
Safety
The caller must ensure that value is either 0 or a valid address in
the current address space.
Sourcepub fn rtti_classname(&self) -> Option<String>
pub fn rtti_classname(&self) -> Option<String>
Returns the class name for this pointer, if it’s pointing to a vftable whose name is in the RTTI.